Skip to content

Commit 66726f0

Browse files
chore(content): sync from Feishu
1 parent 421c415 commit 66726f0

3 files changed

Lines changed: 14 additions & 1 deletion

File tree

docs/.vitepress/data/generated/feishu.json

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -40,7 +40,7 @@
4040
"order": 2,
4141
"documentId": "H5x1dK6LzoVFmuxUzDicmuQ1nbb",
4242
"objectType": "docx",
43-
"revisionId": 1746
43+
"revisionId": 1781
4444
}
4545
]
4646
}
357 KB
Loading

docs/wiki/WHFXw13vEiD8Hikfp3ScU33JnXe.md

Lines changed: 13 additions & 0 deletions
Original file line numberDiff line numberDiff line change
@@ -333,3 +333,16 @@ __global__ void syncthreads_invalid_behavior(int* input_data, int* output_data)
333333
output_data[threadIdx.x] = shared_data[127 - threadIdx.x];
334334
}
335335
```
336+
337+
### Thread Block Cluster
338+
339+
从 CC 9.0 开始,CUDA 引入了⼀个可选的中间层次:Thread Block Cluster。Cluster 中的 block 保证在同⼀个 GPC(Graphics Processing Cluster)上调度,可以实现跨 block 通信。
340+
341+
## 内存层次结构
342+
343+
<FeishuImage src="/feishu/wiki/WHFXw13vEiD8Hikfp3ScU33JnXe/110889978b5afc64f95b0cab.png" caption="整体视图" width="2425" height="1842" transparent />
344+
345+
| 内存类型 | Scope | 生命周期 | 位置 |
346+
|-|-|-|-|
347+
| Global | | | |
348+
| | | | |

0 commit comments

Comments
 (0)